# django-bpmn

Encapsulates the [bpmn-js](https://github.com/bpmn-io/bpmn-js.git) modeler into a Django widget. 
This is not part of the oficial [bpmn-io](https://github.com/bpmn-io/) initiative. 
Take a look at their [license](https://raw.githubusercontent.com/bpmn-io/bpmn-js/develop/LICENSE), specially the explicit forbidden to hide their watermark.